fluxfixer-package: fluxfixer: Advanced Framework for Sap Flow Data Post-Process

fluxfixer-packageR Documentation

fluxfixer: Advanced Framework for Sap Flow Data Post-Process

Description

logo

Provides a flexible framework for post-processing thermal dissipation sap flow data using statistical methods and machine learning. This framework includes anomaly correction, outlier removal, gap-filling, trend removal, signal damping correction, and sap flux density calculation. The functions in this package can also apply to other time series with various artifacts.

Author(s)

Maintainer: Yoshiaki Hata yoshiakihata0806@gmail.com (ORCID) [copyright holder]

See Also

Useful links:


fluxfixer documentation built on April 11, 2026, 5:06 p.m.