get_interval: Obtain time interval of input timestamp vector

View source: R/utils.R

get_intervalR Documentation

Obtain time interval of input timestamp vector

Description

'get_interval()' retrieves the time interval of the input timestamp vector and checks whether the format of the time vector is acceptable for the successive process.

Usage

get_interval(vctr_time)

Arguments

vctr_time

A timestamp vector of class POSIXct or POSIXlt. The timestamps must be equally spaced and arranged chronologically.

Value

A numeric (minutes) indicating the time interval of the input timestamp vector.

Author(s)

Yoshiaki Hata


fluxfixer documentation built on April 11, 2026, 5:06 p.m.