Provides a flexible framework for post-processing thermal dissipation sap flow data using statistical methods and machine learning. This framework includes anomaly correction, outlier removal, gap-filling, trend removal, signal damping correction, and sap flux density calculation. The functions in this package can also apply to other time series with various artifacts.
Maintainer: Yoshiaki Hata yoshiakihata0806@gmail.com (ORCID) [copyright holder]
Useful links: