| get_interval | R Documentation |
'get_interval()' retrieves the time interval of the input timestamp vector and checks whether the format of the time vector is acceptable for the successive process.
get_interval(vctr_time)
vctr_time |
A timestamp vector of class POSIXct or POSIXlt. The timestamps must be equally spaced and arranged chronologically. |
A numeric (minutes) indicating the time interval of the input timestamp vector.
Yoshiaki Hata
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.