| n_valid | R Documentation |
'n_valid()' retrieves the number of data points without missing values.
n_valid(vctr, label_err = -9999)
vctr |
A vector to be evaluated. |
label_err |
A numeric value representing a missing value in the input vector(s). Default is -9999. |
An integer indicating the number of the input vector elements without missing values.
Yoshiaki Hata
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.